/*
 * This script will be injected into all frames and will take care that the CKEDITOR
 * will get informed about changes (for example for auto save component).
 * 
 * We had to create a separate content script for the extension because this was
 * the only way to get access to the CKEDITOR instance.
 * 
 * A better way would be if we can trigger DOM events that the CKEDITOR will listen to
 * which will lead to the same result, but I was unable to fake the required DOM events
 * (CKEDITOR did ignore them entirely when created programatically). Would need deeper
 * investigation to make it work.
 * 
 * The problem with the current appraoch is that we are probably bound to specific versions
 * of CKEDITOR and need to update this script, when things getting changed.
 */
chrome.runtime.sendMessage({}, (response) => {
    if (chrome.runtime.lastError) {
        console.warn(chrome.runtime.lastError.message);            
    }

    const readyStateCheckInterval = setInterval(() => {
        if (document.readyState === "complete") {
            if (!document.body) {
                return;
            }

            var script = document.createElement('script');
            script.type = 'text/javascript';
            script.innerHTML = `window.addEventListener("message", function (event) { 
                    if (event.data === 'content_changed') {
                        if (typeof(CKEDITOR) !== 'undefined' && typeof(CKEDITOR.instances) !== 'undefined') {
                            for (var key in CKEDITOR.instances) {
                                var editor = CKEDITOR.instances[key];
                                editor.fire('saveSnapshot');
                            }
                        }
                    }

                    // forward message to child frames
                    var frames = document.getElementsByTagName("iframe");
                    for (var i = 0; i < frames.length; i++) {
                        frames[i].contentWindow.postMessage(event.data);
                    }
                }, true);
                `;
            document.body.append(script);
            clearInterval(readyStateCheckInterval);
        }
    }, 250);
});
